@@ -1,10 +1,11 @@
 package Pipe::Tube::Sort;
 use strict;
 use warnings;
+use 5.006;
 
 use base 'Pipe::Tube';
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub init {
     my ($self, $expr) = @_;
@@ -22,13 +23,17 @@ sub run {
 
 sub finish {
     my ($self) = @_;
+
     $self->logger("The sort expression: " . (defined $self->{expr} ? $self->{expr} : ''));
+
     my $sub = $self->{expr};
+	my @sorted;
     if (defined $sub) {
-        return sort { $sub->($a, $b) } @{ $self->{data} };
+        @sorted = sort { $sub->($a, $b) } @{ $self->{data} };
     } else {
-        return sort @{ $self->{data} };
+        @sorted = sort @{ $self->{data} };
     }
+	return @sorted;
 }
 
 1;
